Learn R Programming

HH (version 3.1-47)

combineLimits.trellisvector: Combine limits on a one-dimensional trellis object.

Description

Combine limits on a one-dimensional trellis object.

Usage

combineLimits.trellisvector(x, margin.x = 1:2, margin.y = 1:2,
                            layout = x$layout,
                            ncol=x$layout[1], nrow=x$layout[2],
                            condlevels = x$condlevels[[1]], ...)

Arguments

x

trellis object.

margin.x, margin.y
layout

See xyplot.

condlevels

Character. Names of each panel of the result. Defaults to the names of the panels of the argument.

…

Other arguments are ignored.

nrow, ncol

See matrix.trellis. These arguments default to the levels of x$layout if it is non-null. Otherwise nrow==1 and ncol==dim(x).

Value

One-dimensional trellis object with combined xlim and ylim values across all panels.

Details

The one-dimensional object is converted to a two-dimensional object which is forwarded to the standard combineLimits function. The result is converted back to a one-dimensional object.

See Also

combineLimits

Examples

Run this code
# NOT RUN {
tmp <- data.frame(a=1:3,
                  b=c(4,5,7),
                  c=5:7,
                  d=c(8, 9, 12),
                  e=9:11)
tmp

a2 <- xyplot(a + b ~ c + d + e, data=tmp, outer=TRUE,
             scales=list(relation="free"), main="a2")
a2
dim(a2)
combineLimits.trellisvector(a2)
a21 <- combineLimits.trellisvector(update(a2, layout=c(3,2)))
a21
dim(a21)
# }

Run the code above in your browser using DataLab