glht.mcp.993(model, linfct, ...)
mcp2matrix.993(model, linfct)
mcp2matrix2(model, linfct, interaction.average=FALSE, covariate.average=FALSE)
glht.mcp(model, linfct, ..., interaction.average=FALSE, covariate.average=FALSE)glhtFALSE.glhtmcp2matrix is taken from from multcomp_0.993-2.tar.gz/R/mcp.R.
mcp2matrix2 is styled after mcp2matrix in multcomp_1.0-7, with
optional averaging of interactions based on
multcomp_0.993-1. In addition it offers optional averaging of
covariates to get the same answer as S-Plus multicomp.
With the default value of both new arguments at
FALSE, mcp2matrix2 behaves exactly like
mcp2matrix.
glht.mcp.993 is based on glht.mcp in
multcomp_1.0-0/R/glht.R
with the call to mcp2matrix replaced by a call to mcp2matrix.993.
glht.mcp is based on glht.mcp in
multcomp_1.0-0/R/glht.R with two changes. The call to
mcp2matrix is replaced by a call to mcp2matrix2. The new
arguments interaction.average and covariate.average are
passed to mcp2matrix2 and not forwarded to any other downstream
function. With the default value of both new arguments at FALSE,
mcp2matrix2 behaves exactly like multcomp:::glht.mcp.MMC