is.likert(x)
as.likert(x, ...)
## S3 method for class 'likert':
as.likert(x, ...)
## S3 method for class 'data.frame':
as.likert(x, ...)
## S3 method for class 'formula':
as.likert(x, ...) ## doesn't work yet
## S3 method for class 'ftable':
as.likert(x, ...)
## S3 method for class 'table':
as.likert(x, ...)
## S3 method for class 'matrix':
as.likert(x, rowlabel=NULL, collabel=NULL, ..., reverse=FALSE)
## S3 method for class 'numeric':
as.likert(x, ...)
is.likertCapable(x, ...)as.likert methods, a numeric object stored as a vector, matrix,
two-dimensional table, two-dimensional ftable, or
two-dimensional structable (as defined in the vcd package).
For is.likert and <names(dimnames(x)), where x is
the argument to the as.likert functions.
These will become the xlab and ylab of the likert plot.as.likert method.TRUE, reverse the rows in the result.as.likert methods, a likert object, which is
a matrix with additional attributes that are needed to make the
barchart method used by the plot.likert methods
work with the data. Columns for respondents who
disagree have negated values.
The column of the original data for respondents who
neither agree nor disagree is split into two columns, each containing
halved values---one positive and one negative.
Negative columns come first in the sequence of "No Opinion"(negative)--"Strongly
Disagree",
followed by "No Opinion"(positive)--"Strongly Agree".
There are four
attributes:
"even.col" indicating whether there were originally an even
number of columns, "n.levels" the original number of levels,
"levels"
the original levels in the original order, "positive.order"
The sequence in which to display the rows in order to make the right
hand sides progress with high values on top.
is.likert returns a TRUE or FALSE value.
is.likertCapable returns a TRUE or FALSE value
if the argument can used as an argument to one of the plot.likert methods.likert for information on the plot for which
as.likert prepares the data.likert## Please see ?likert to see these functions used in context.
tmp2 <- array(1:12, dim=c(3,4), dimnames=list(B=LETTERS[3:5], C=letters[6:9]))
as.likert(tmp2) ## even number of levels.
is.likert(tmp2)
is.likert(as.likert(tmp2))Run the code above in your browser using DataLab